@@ -108,6 +108,8 @@ as.dendrogram.igraph.walktrap <- function (object, hang=-1,
                                            use.modularity=FALSE, ...)
 {
   stopifnot(nrow(object$merges)> 0)
+  storage.mode(object$merges) <- "integer"
+  object$merges <- object$merges + 1L
   if (is.null(object$labels))
     object$labels <- 1:(nrow(object$merges)+1)-1
   z <- list()
@@ -126,13 +128,13 @@ as.dendrogram.igraph.walktrap <- function (object, hang=-1,
   leafs <- nrow(object$merges)+1
   for (k in 1:nMerge) {
     x <- object$merges[k, ]# no sort() anymore!
-    if (any(neg <- x < leafs))
+    if (any(neg <- x < leafs+1))
       h0 <- if (hang < 0) 0 else max(0, oHgt[k] - hang * hMax)
     if (all(neg)) {                  # two leaves
       zk <- as.list(x)
       attr(zk, "members") <- two
       attr(zk, "midpoint") <- 0.5 # mean( c(0,1) )
-      objlabels <- object$labels[x+1]
+      objlabels <- object$labels[x]
       attr(zk[[1]], "label") <- objlabels[1]
       attr(zk[[2]], "label") <- objlabels[2]
       attr(zk[[1]], "members") <- attr(zk[[2]], "members") <- one
@@ -143,7 +145,7 @@ as.dendrogram.igraph.walktrap <- function (object, hang=-1,
       X <- as.character(x)
       ## Originally had "x <- sort(..) above => leaf always left, x[1];
       ## don't want to assume this
-      isL <- x[1] < leafs ## is leaf left?
+      isL <- x[1] < leafs+1 ## is leaf left?
       zk <-
         if(isL) list(x[1], z[[X[2]]])
         else    list(z[[X[1]]], x[2])
@@ -152,7 +154,7 @@ as.dendrogram.igraph.walktrap <- function (object, hang=-1,
         (.memberDend(zk[[1]]) + attr(z[[X[1 + isL]]], "midpoint"))/2
       attr(zk[[2 - isL]], "members") <- one
       attr(zk[[2 - isL]], "height") <- h0
-      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]+1]
+      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]]
       attr(zk[[2 - isL]], "leaf") <- TRUE
       }
     else {                        # two nodes
@@ -165,7 +167,7 @@ as.dendrogram.igraph.walktrap <- function (object, hang=-1,
                                attr(z[[x[2]]], "midpoint"))/2
     }
     attr(zk, "height") <- oHgt[k]
-    z[[k <- as.character(k+leafs-1)]] <- zk
+    z[[k <- as.character(k+leafs)]] <- zk
   }
   z <- z[[k]]
   class(z) <- "dendrogram"
@@ -215,6 +217,8 @@ as.dendrogram.igraph.ebc <- function (object, hang=-1,
     object$merges <- merges
   }
   stopifnot(nrow(object$merges)> 0)
+  storage.mode(object$merges) <- "integer"
+  object$merges <- object$merges + 1L
   if (is.null(object$labels))
     object$labels <- 1:(nrow(object$merges)+1)-1
   z <- list()
@@ -233,13 +237,13 @@ as.dendrogram.igraph.ebc <- function (object, hang=-1,
   leafs <- nrow(object$merges)+1
   for (k in 1:nMerge) {
     x <- object$merges[k, ]# no sort() anymore!
-    if (any(neg <- x < leafs))
+    if (any(neg <- x < leafs+1))
       h0 <- if (hang < 0) 0 else max(0, oHgt[k] - hang * hMax)
     if (all(neg)) {                  # two leaves
       zk <- as.list(x)
       attr(zk, "members") <- two
       attr(zk, "midpoint") <- 0.5 # mean( c(0,1) )
-      objlabels <- object$labels[x+1]
+      objlabels <- object$labels[x]
       attr(zk[[1]], "label") <- objlabels[1]
       attr(zk[[2]], "label") <- objlabels[2]
       attr(zk[[1]], "members") <- attr(zk[[2]], "members") <- one
@@ -250,7 +254,7 @@ as.dendrogram.igraph.ebc <- function (object, hang=-1,
       X <- as.character(x)
       ## Originally had "x <- sort(..) above => leaf always left, x[1];
       ## don't want to assume this
-      isL <- x[1] < leafs ## is leaf left?
+      isL <- x[1] < leafs+1 ## is leaf left?
       zk <-
         if(isL) list(x[1], z[[X[2]]])
         else    list(z[[X[1]]], x[2])
@@ -259,7 +263,7 @@ as.dendrogram.igraph.ebc <- function (object, hang=-1,
         (.memberDend(zk[[1]]) + attr(z[[X[1 + isL]]], "midpoint"))/2
       attr(zk[[2 - isL]], "members") <- one
       attr(zk[[2 - isL]], "height") <- h0
-      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]+1]
+      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]]
       attr(zk[[2 - isL]], "leaf") <- TRUE
       }
     else {                        # two nodes
@@ -272,7 +276,7 @@ as.dendrogram.igraph.ebc <- function (object, hang=-1,
                                attr(z[[x[2]]], "midpoint"))/2
     }
     attr(zk, "height") <- oHgt[k]
-    z[[k <- as.character(k+leafs-1)]] <- zk
+    z[[k <- as.character(k+leafs)]] <- zk
   }
   z <- z[[k]]
   class(z) <- "dendrogram"
@@ -344,6 +348,8 @@ as.dendrogram.igraph.eigenc <- function(object, hang=-1,
     object$merges <- merges
   }
   stopifnot(nrow(object$merges)>0)
+  storage.mode(object$merges) <- "integer"
+  object$merges <- object$merges + 1L
   if (is.null(object$labels)) {
     labels <- character()
     for (i in 1:max(object$membership+1)) {
@@ -363,13 +369,13 @@ as.dendrogram.igraph.eigenc <- function(object, hang=-1,
   leafs <- nrow(object$merges)+1
   for (k in 1:nMerge) {
     x <- object$merges[k, ]# no sort() anymore!
-    if (any(neg <- x < leafs))
+    if (any(neg <- x < leafs+1))
       h0 <- if (hang < 0) 0 else max(0, oHgt[k] - hang * hMax)
     if (all(neg)) {                  # two leaves
       zk <- as.list(x)
       attr(zk, "members") <- two
       attr(zk, "midpoint") <- 0.5 # mean( c(0,1) )
-      objlabels <- object$labels[x+1]
+      objlabels <- object$labels[x]
       attr(zk[[1]], "label") <- objlabels[1]
       attr(zk[[2]], "label") <- objlabels[2]
       attr(zk[[1]], "members") <- attr(zk[[2]], "members") <- one
@@ -380,7 +386,7 @@ as.dendrogram.igraph.eigenc <- function(object, hang=-1,
       X <- as.character(x)
       ## Originally had "x <- sort(..) above => leaf always left, x[1];
       ## don't want to assume this
-      isL <- x[1] < leafs ## is leaf left?
+      isL <- x[1] < leafs+1 ## is leaf left?
       zk <-
         if(isL) list(x[1], z[[X[2]]])
         else    list(z[[X[1]]], x[2])
@@ -389,7 +395,7 @@ as.dendrogram.igraph.eigenc <- function(object, hang=-1,
         (.memberDend(zk[[1]]) + attr(z[[X[1 + isL]]], "midpoint"))/2
       attr(zk[[2 - isL]], "members") <- one
       attr(zk[[2 - isL]], "height") <- h0
-      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]+1]
+      attr(zk[[2 - isL]], "label") <- object$labels[x[2 - isL]]
       attr(zk[[2 - isL]], "leaf") <- TRUE
       }
     else {                        # two nodes
@@ -402,7 +408,7 @@ as.dendrogram.igraph.eigenc <- function(object, hang=-1,
                                attr(z[[x[2]]], "midpoint"))/2
     }
     attr(zk, "height") <- oHgt[k]
-    z[[k <- as.character(k+leafs-1)]] <- zk
+    z[[k <- as.character(k+leafs)]] <- zk
   }
   z <- z[[k]]
   class(z) <- "dendrogram"
