@@ -35,8 +35,8 @@ graph.maxflow <- function(graph, source, target, capacity=NULL) {
   }
   
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_maxflow", graph, as.numeric(source), as.numeric(target),
-        capacity,
+  .Call("R_igraph_maxflow", graph, as.igraph.vs(graph, source),
+        as.igraph.vs(graph, target), capacity,
         PACKAGE="igraph")
 }
 
@@ -71,8 +71,8 @@ graph.mincut <- function(graph, source=NULL, target=NULL, capacity=NULL,
     }
   } else {
     if (value.only) {
-      .Call("R_igraph_st_mincut_value", graph, as.numeric(source),
-            as.numeric(target), capacity,
+      .Call("R_igraph_st_mincut_value", graph, as.igraph.vs(graph, source),
+            as.igraph.vs(graph, target), capacity,
             PACKAGE="igraph")
     } else {
       stop("Calculating minimum s-t cuts is not implemented yet")
@@ -92,8 +92,8 @@ vertex.connectivity <- function(graph, source=NULL, target=NULL, checks=TRUE) {
           PACKAGE="igraph")
   } else if (!is.null(source) && !is.null(target)) {
     on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-    .Call("R_igraph_st_vertex_connectivity", graph, as.numeric(source),
-          as.numeric(target),
+    .Call("R_igraph_st_vertex_connectivity", graph, as.igraph.vs(graph, source),
+          as.igraph.vs(graph, target),
           PACKAGE="igraph")
   } else {
     stop("either give both source and target or neither")
@@ -113,7 +113,7 @@ edge.connectivity <- function(graph, source=NULL, target=NULL, checks=TRUE) {
   } else if (!is.null(source) && !is.null(target)) {
     on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
     .Call("R_igraph_st_edge_connectivity", graph,
-          as.numeric(source), as.numeric(target),
+          as.igraph.vs(graph, source), as.igraph.vs(graph, target),
           PACKAGE="igraph")
   } else {
     stop("either give both source and target or neither")
@@ -128,7 +128,7 @@ edge.disjoint.paths <- function(graph, source, target) {
 
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
   .Call("R_igraph_edge_disjoint_paths", graph,
-        as.numeric(source), as.numeric(target),
+        as.igraph.vs(graph, source), as.igraph.vs(graph, target),
         PACKAGE="igraph")
 }
 
@@ -139,8 +139,8 @@ vertex.disjoint.paths <- function(graph, source=NULL, target=NULL) {
   }
 
   on.exit( .Call("R_igraph_finalizer", PACKAGE="igraph") )
-  .Call("R_igraph_vertex_disjoint_paths", graph, as.numeric(source),
-        as.numeric(target),
+  .Call("R_igraph_vertex_disjoint_paths", graph, as.igraph.vs(graph, source),
+        as.igraph.vs(graph, target),
         PACKAGE="igraph")
 }
 
