@@ -1556,7 +1556,7 @@ int igraph_write_graph_ncol(const igraph_t *graph, FILE *outstream,
     igraph_vector_t wvec;
     IGRAPH_VECTOR_INIT_FINALLY(&wvec, igraph_ecount(graph));
     IGRAPH_CHECK(igraph_i_attribute_get_numeric_edge_attr(graph, weights, 
-							 igraph_ess_all(IGRAPH_EDGEORDER_FROM), 
+							 igraph_ess_all(IGRAPH_EDGEORDER_ID), 
 							 &wvec));
     while (!IGRAPH_EIT_END(it)) {
       igraph_integer_t edge=IGRAPH_EIT_GET(it);
@@ -1580,7 +1580,7 @@ int igraph_write_graph_ncol(const igraph_t *graph, FILE *outstream,
     IGRAPH_CHECK(igraph_strvector_init(&nvec, igraph_vcount(graph)));
     IGRAPH_FINALLY(igraph_strvector_destroy, &nvec);
     IGRAPH_CHECK(igraph_i_attribute_get_numeric_edge_attr(graph, weights, 
-							 igraph_ess_all(IGRAPH_EDGEORDER_FROM), 
+							 igraph_ess_all(IGRAPH_EDGEORDER_ID), 
 							 &wvec));
     IGRAPH_CHECK(igraph_i_attribute_get_string_vertex_attr(graph, names, 
 							   igraph_vss_all(),
@@ -1742,7 +1742,7 @@ int igraph_write_graph_lgl(const igraph_t *graph, FILE *outstream,
     IGRAPH_CHECK(igraph_strvector_init(&wvec, igraph_ecount(graph)));
     IGRAPH_FINALLY(igraph_strvector_destroy, &wvec);
     IGRAPH_CHECK(igraph_i_attribute_get_string_edge_attr(graph, weights,
-							 igraph_ess_all(IGRAPH_EDGEORDER_FROM),
+							 igraph_ess_all(IGRAPH_EDGEORDER_ID),
 							 &wvec));
     /* No names but weights */
     while (!IGRAPH_EIT_END(it)) {
@@ -1773,7 +1773,7 @@ int igraph_write_graph_lgl(const igraph_t *graph, FILE *outstream,
     IGRAPH_CHECK(igraph_strvector_init(&nvec, igraph_vcount(graph)));
     IGRAPH_FINALLY(igraph_strvector_destroy, &nvec);
     IGRAPH_CHECK(igraph_i_attribute_get_string_edge_attr(graph, weights,
-							 igraph_ess_all(IGRAPH_EDGEORDER_FROM),
+							 igraph_ess_all(IGRAPH_EDGEORDER_ID),
 							 &wvec));
     IGRAPH_CHECK(igraph_i_attribute_get_string_vertex_attr(graph, names, 
 							   igraph_vss_all(),
@@ -2053,6 +2053,8 @@ int igraph_write_graph_pajek(const igraph_t *graph, FILE *outstream) {
 						  igraph_vss_1(i), &strv);
 	igraph_strvector_get(&strv, 0, &s);
 	fprintf(outstream, " \"%s\"", s);
+      } else {
+	fprintf(outstream, " \"%li\"", i+1);
       }
       
       /* coordinates */
@@ -2268,10 +2270,9 @@ int igraph_i_gml_convert_to_key(const char *orig, char **key) {
   static int no=1;
   char strno[50];
   long int i, len=strlen(orig), newlen=0, plen=0;
-  igraph_bool_t pref=0;  
   /* do we need a prefix? */
   if (len==0 || !isalpha(orig[0])) { 
-    pref=1; no++;
+    no++;
     snprintf(strno, sizeof(strno)-1, "igraph");
     plen=newlen=strlen(strno);
   }
