@@ -111,7 +111,6 @@ degree_sequence::degree_sequence(FILE *f, bool DISTRIB) {
     while(fgets(buff, FBUFF_SIZE, f)) {
       line++;
       int d = strtol(buff, &c, 10);
-      long int tmp;
       if(c == buff) { ignored++; first_ignored = line; continue; }
       char *cc;
       int i = strtol(c, &cc, 10);
@@ -120,7 +119,6 @@ degree_sequence::degree_sequence(FILE *f, bool DISTRIB) {
       total += i*d;
       degree.push_back(d);
       n_with_degree.push_back(i);
-      tmp=strtol(cc, &c, 10);
       if( cc != c) {  syntax++; first_syntax = line; }
     }
     if(VERBOSE()) {
